"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isIgnoredPath = void 0;
// builtin
var path_1 = require("path");
// external
var ignorepatterns_1 = __importDefault(require("ignorepatterns"));
/**
 * Is Ignored Path
 * Check to see if a path, either a full path or basename, should be ignored
 * @param path full path or basename of a file or directory
 * @param opts configuration options
 * @returns whether or not the path should be ignored
 */
function isIgnoredPath(path, opts) {
    if (opts === void 0) { opts = {}; }
    // Prepare
    var basename = (0, path_1.basename)(path);
    // Test Paths
    if (opts.ignorePaths) {
        for (var i = 0; i < opts.ignorePaths.length; ++i) {
            var ignorePath = opts.ignorePaths[i];
            if (path.indexOf(ignorePath) === 0) {
                return true;
            }
        }
    }
    // Test Hidden Files
    if (opts.ignoreHiddenFiles && basename[0] === '.') {
        return true;
    }
    // Test Common Patterns
    if (opts.ignoreCommonPatterns == null || opts.ignoreCommonPatterns === true) {
        return (ignorepatterns_1.default.test(path) ||
            (path !== basename && ignorepatterns_1.default.test(basename)));
    }
    else if (opts.ignoreCommonPatterns) {
        var ignoreCommonPatterns /* :RegExp */ = opts.ignoreCommonPatterns;
        return (ignoreCommonPatterns.test(path) ||
            (path !== basename && ignoreCommonPatterns.test(basename)));
    }
    // Test Custom Patterns
    if (opts.ignoreCustomPatterns) {
        var ignoreCustomPatterns /* :RegExp */ = opts.ignoreCustomPatterns;
        return (ignoreCustomPatterns.test(path) ||
            (path !== basename && ignoreCustomPatterns.test(basename)));
    }
    // Return
    return false;
}
exports.isIgnoredPath = isIgnoredPath;
